Flake8 CNS-OIST plugin
======================
Check usage of STEPS subcellular simulator Python API.


Install
-------
Install with pip::

   $ pip install flake8-oist-steps


Requirements
------------
- Python 3.5, 3.6, 3.7, or 3.8
- flake8


Usage
-----
Use regular flake8 command to check your scripts::

   $ flake8 my-steps-script.py


License
-------
GPL 2.0
